#!/bin/sh

#prefix=$1
#shift
#pymake=$*

(	cd lib
	mkdir	-p .tmp
	../../../sip/sip/sip -c .tmp rekall.sip || exit
	cd	.tmp

	for f in *
	do
		grep -s -v Generated $f    > .1
		grep -s -v Generated ../$f > .2

		cmp -s .1 .2 || {
			echo	Updating $f ...
			mv	$f ..
		}
	done

	cd ..
	rm -rf .tmp

	[ "`hostname`" = "henley.seriesone.net" ] && ./extract
)


#./link.sh
#
#for pyver in $pymake
#do
#	(
#		cd lib-${pyver}
#		make $MMAKE_JOBS || exit 1
#	)	|| exit 1
#	(
#		cd lib-${pyver}_rt
#		make $MMAKE_JOBS || exit 1
#	)	|| exit 1
#done
#
#(
#	cd stub
#	cmp -s ../lib/Rekall.py Rekall.py || cp ../lib/Rekall.py Rekall.py
#	make || exit 1
#)
#(
#	cd stub_rt
#	cmp -s ../lib/Rekall.py Rekall.py || cp ../lib/Rekall.py Rekall.py
#	make || exit 1
#)

